

set -ex



test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.a
test -f ${PREFIX}/lib/libpython${PKG_VERSION%.*}.nolto.a
pushd tests
pushd embedding-interpreter
bash build-and-test.sh
popd
popd
exit 0
